/*--------------------------------------------------------------------------*/
/* Copyright 2018-2023 NXP                                                  */
/*                                                                          */
/* NXP Confidential. This software is owned or controlled by NXP and may    */
/* only be used strictly in accordance with the applicable license terms.   */
/* By expressly accepting such terms or by downloading, installing,         */
/* activating and/or otherwise using the software, you are agreeing that    */
/* you have read, and that you agree to comply with and are bound by, such  */
/* license terms. If you do not agree to be bound by the applicable license */
/* terms, then you may not retain, install, activate or otherwise use the   */
/* software.                                                                */
/*--------------------------------------------------------------------------*/

/*
 * @file: mcuxClOsccaSm2_FUP.c
 * @brief FUP programs for SM2
 */

#include <mcuxClOscca_Types.h>
#include <mcuxClOscca_PlatformTypes.h>
#include <internal/mcuxClOsccaSm2_Internal.h>

MCUX_CSSL_ANALYSIS_START_PATTERN_FUP_PROGRAM()
const mcuxClOsccaPkc_FUPEntry_t mcuxClOsccaSm2_FUP_CheckRPlusS[5] = {{0x10u,0x00u,0x22u,0x87u,0xebu,0x8du},{0x80u,0x21u,0x07u,0x10u,0x20u,0x0au},{0x80u,0x2au,0x07u,0x0au,0x07u,0x10u},{0x80u,0x33u,0x10u,0x10u,0x07u,0x0au},{0x80u,0x2au,0x07u,0x0au,0x07u,0x0bu}};
const mcuxClOsccaPkc_FUPEntry_t mcuxClOsccaSm2_FUP_CheckSignature[5] = {{0x10u,0x00u,0x3eu,0x68u,0x98u,0x69u},{0x80u,0x21u,0x07u,0x0au,0x01u,0x0au},{0x80u,0x2au,0x07u,0x0au,0x0cu,0x0du},{0x80u,0x33u,0x0du,0x0du,0x07u,0x0au},{0x80u,0x2au,0x07u,0x0au,0x07u,0x0du}};
const mcuxClOsccaPkc_FUPEntry_t mcuxClOsccaSm2_FUP_EccImportInputPointInputPointWithInit_PrepareZ23[4] = {{0x10u,0x00u,0x15u,0x6fu,0x7bu,0xb5u},{0x80u,0x00u,0x0fu,0x0fu,0x00u,0x0cu},{0x80u,0x00u,0x0cu,0x1au,0x00u,0x0au},{0x80u,0x00u,0x0fu,0x0au,0x00u,0x0cu}};
const mcuxClOsccaPkc_FUPEntry_t mcuxClOsccaSm2_FUP_EccPointConvert2Affine_PrepareZ3[5] = {{0x10u,0x00u,0x90u,0x91u,0x30u,0xe0u},{0x80u,0x00u,0x03u,0x0fu,0x00u,0x0bu},{0x00u,0x0eu,0x0bu,0x0bu,0x25u,0x03u},{0x80u,0x00u,0x0bu,0x0bu,0x00u,0x0du},{0x80u,0x33u,0x0du,0x0du,0x00u,0x0cu}};
const mcuxClOsccaPkc_FUPEntry_t mcuxClOsccaSm2_FUP_EccPointMultMontgomery_CopyP0P1[4] = {{0x10u,0x00u,0x39u,0x33u,0x32u,0x94u},{0x00u,0x0eu,0x14u,0x14u,0x25u,0x11u},{0x00u,0x0eu,0x15u,0x15u,0x25u,0x12u},{0x00u,0x0eu,0x16u,0x16u,0x25u,0x13u}};
const mcuxClOsccaPkc_FUPEntry_t mcuxClOsccaSm2_FUP_EccPointMultMontgomery_CopyP1P0[4] = {{0x10u,0x00u,0x42u,0xc5u,0x1bu,0x47u},{0x00u,0x0eu,0x11u,0x11u,0x25u,0x14u},{0x00u,0x0eu,0x12u,0x12u,0x25u,0x15u},{0x00u,0x0eu,0x13u,0x13u,0x25u,0x16u}};
const mcuxClOsccaPkc_FUPEntry_t mcuxClOsccaSm2_FUP_EccPointMultMontgomery_InitPoints[7] = {{0x10u,0x00u,0x67u,0xa0u,0xf6u,0x39u},{0x00u,0x0fu,0x25u,0x25u,0x25u,0x11u},{0x00u,0x0fu,0x25u,0x25u,0x25u,0x12u},{0x00u,0x0fu,0x25u,0x25u,0x25u,0x13u},{0x00u,0x0eu,0x14u,0x14u,0x25u,0x17u},{0x00u,0x0eu,0x15u,0x15u,0x25u,0x18u},{0x00u,0x09u,0x00u,0x00u,0x00u,0x16u}};
const mcuxClOsccaPkc_FUPEntry_t mcuxClOsccaSm2_FUP_EccTransAffinePoint2Jac[8] = {{0x10u,0x00u,0xcbu,0x40u,0xa7u,0x58u},{0x80u,0x00u,0x0fu,0x0fu,0x00u,0x0cu},{0x80u,0x00u,0x0cu,0x1au,0x00u,0x0au},{0x80u,0x00u,0x0fu,0x0au,0x00u,0x0cu},{0x00u,0x0eu,0x01u,0x01u,0x01u,0x0du},{0x80u,0x00u,0x0du,0x0au,0x00u,0x01u},{0x00u,0x0eu,0x02u,0x02u,0x02u,0x0du},{0x80u,0x00u,0x0du,0x0cu,0x00u,0x02u}};
const mcuxClOsccaPkc_FUPEntry_t mcuxClOsccaSm2_FUP_InvertPrivateKey[9] = {{0x10u,0x00u,0x9bu,0x9bu,0x55u,0xebu},{0x80u,0x00u,0x05u,0x06u,0x02u,0x07u},{0x80u,0x21u,0x03u,0x05u,0x00u,0x05u},{0x80u,0x00u,0x05u,0x06u,0x02u,0x08u},{0x80u,0x33u,0x06u,0x06u,0x02u,0x05u},{0x80u,0x21u,0x03u,0x05u,0x08u,0x08u},{0x80u,0x2au,0x03u,0x08u,0x07u,0x08u},{0x80u,0x33u,0x08u,0x08u,0x02u,0x06u},{0x80u,0x2au,0x02u,0x06u,0x02u,0x06u}};
const mcuxClOsccaPkc_FUPEntry_t mcuxClOsccaSm2_FUP_JacPointCheck[16] = {{0x10u,0x00u,0x17u,0xd9u,0x80u,0xa2u},{0x80u,0x00u,0x03u,0x0fu,0x00u,0x0bu},{0x80u,0x00u,0x0bu,0x0bu,0x00u,0x0au},{0x80u,0x00u,0x0au,0x0au,0x00u,0x0bu},{0x80u,0x00u,0x0bu,0x09u,0x00u,0x0cu},{0x80u,0x00u,0x01u,0x0cu,0x00u,0x0du},{0x80u,0x00u,0x0au,0x0bu,0x00u,0x0cu},{0x80u,0x00u,0x0cu,0x1cu,0x00u,0x0bu},{0x80u,0x21u,0x0eu,0x0du,0x0bu,0x0cu},{0x80u,0x00u,0x01u,0x01u,0x00u,0x0au},{0x80u,0x00u,0x0au,0x01u,0x00u,0x0bu},{0x80u,0x21u,0x0eu,0x0cu,0x0bu,0x0du},{0x80u,0x00u,0x02u,0x02u,0x00u,0x0cu},{0x80u,0x2au,0x0eu,0x0cu,0x0du,0x0bu},{0x80u,0x33u,0x0bu,0x0bu,0x00u,0x0cu},{0x80u,0x2au,0x00u,0x0cu,0x00u,0x0bu}};
const mcuxClOsccaPkc_FUPEntry_t mcuxClOsccaSm2_FUP_KeyExchgCalcTa[11] = {{0x10u,0x00u,0xc8u,0x48u,0xf8u,0x20u},{0x80u,0x21u,0x07u,0x0bu,0x0cu,0x0bu},{0x80u,0x00u,0x10u,0x22u,0x07u,0x20u},{0x80u,0x2au,0x07u,0x20u,0x07u,0x10u},{0x80u,0x00u,0x10u,0x0cu,0x07u,0x20u},{0x80u,0x2au,0x07u,0x20u,0x07u,0x0cu},{0x80u,0x00u,0x10u,0x0bu,0x07u,0x20u},{0x80u,0x21u,0x07u,0x0au,0x20u,0x0au},{0x80u,0x2au,0x07u,0x0au,0x07u,0x0au},{0x80u,0x2au,0x07u,0x0au,0x07u,0x0au},{0x80u,0x2au,0x07u,0x0au,0x0cu,0x10u}};
const mcuxClOsccaPkc_FUPEntry_t mcuxClOsccaSm2_FUP_PointAdd[20] = {{0x10u,0x00u,0xb2u,0x4bu,0xd8u,0xa6u},{0x80u,0x00u,0x03u,0x03u,0x00u,0x0au},{0x80u,0x00u,0x03u,0x0au,0x00u,0x0bu},{0x80u,0x00u,0x04u,0x0au,0x00u,0x0cu},{0x80u,0x00u,0x05u,0x0bu,0x00u,0x0du},{0x80u,0x2au,0x0eu,0x02u,0x0du,0x0bu},{0x80u,0x2au,0x0eu,0x01u,0x0cu,0x0du},{0x80u,0x00u,0x03u,0x0du,0x00u,0x0au},{0x00u,0x0eu,0x0au,0x0au,0x0au,0x03u},{0x80u,0x00u,0x0du,0x0du,0x00u,0x0au},{0x80u,0x00u,0x0cu,0x0au,0x00u,0x0du},{0x80u,0x00u,0x01u,0x0au,0x00u,0x0cu},{0x80u,0x00u,0x0bu,0x0bu,0x00u,0x01u},{0x80u,0x2au,0x0eu,0x01u,0x0du,0x0au},{0x80u,0x2au,0x0eu,0x0au,0x0cu,0x01u},{0x80u,0x2au,0x0eu,0x0cu,0x0du,0x0au},{0x80u,0x00u,0x02u,0x0au,0x00u,0x0du},{0x80u,0x2au,0x0eu,0x0cu,0x01u,0x02u},{0x80u,0x00u,0x02u,0x0bu,0x00u,0x0au},{0x80u,0x2au,0x0eu,0x0au,0x0du,0x02u}};
const mcuxClOsccaPkc_FUPEntry_t mcuxClOsccaSm2_FUP_PointCheckCoordinateNegY[4] = {{0x10u,0x00u,0xb1u,0x3eu,0xdfu,0x9bu},{0x80u,0x21u,0x0eu,0x0au,0x02u,0x0cu},{0x80u,0x33u,0x0cu,0x0cu,0x00u,0x0bu},{0x80u,0x2au,0x00u,0x0bu,0x00u,0x0cu}};
const mcuxClOsccaPkc_FUPEntry_t mcuxClOsccaSm2_FUP_PointCheckCoordinateX[6] = {{0x10u,0x00u,0x9du,0x74u,0xc4u,0x05u},{0x80u,0x00u,0x03u,0x03u,0x00u,0x0du},{0x80u,0x00u,0x04u,0x0du,0x00u,0x0au},{0x80u,0x2au,0x0eu,0x0au,0x01u,0x0cu},{0x80u,0x33u,0x0cu,0x0cu,0x00u,0x0bu},{0x80u,0x2au,0x00u,0x0bu,0x00u,0x0cu}};
const mcuxClOsccaPkc_FUPEntry_t mcuxClOsccaSm2_FUP_PointCheckCoordinateY[6] = {{0x10u,0x00u,0xb8u,0x22u,0xdau,0xfbu},{0x80u,0x00u,0x0du,0x03u,0x00u,0x0bu},{0x80u,0x00u,0x05u,0x0bu,0x00u,0x0au},{0x80u,0x2au,0x0eu,0x0au,0x02u,0x0cu},{0x80u,0x33u,0x0cu,0x0cu,0x00u,0x0bu},{0x80u,0x2au,0x00u,0x0bu,0x00u,0x0cu}};
const mcuxClOsccaPkc_FUPEntry_t mcuxClOsccaSm2_FUP_PointDouble[23] = {{0x10u,0x00u,0xdbu,0x08u,0x93u,0xa4u},{0x80u,0x00u,0x03u,0x0fu,0x00u,0x0bu},{0x80u,0x00u,0x0bu,0x0bu,0x00u,0x0au},{0x80u,0x00u,0x0au,0x0au,0x00u,0x0bu},{0x80u,0x00u,0x0bu,0x09u,0x00u,0x0au},{0x80u,0x00u,0x01u,0x01u,0x00u,0x0cu},{0x80u,0x21u,0x0eu,0x0cu,0x0cu,0x0bu},{0x80u,0x21u,0x0eu,0x0bu,0x0cu,0x0du},{0x80u,0x21u,0x0eu,0x0du,0x0au,0x0bu},{0x80u,0x00u,0x02u,0x03u,0x00u,0x0du},{0x80u,0x21u,0x0eu,0x0du,0x0du,0x03u},{0x80u,0x00u,0x02u,0x02u,0x00u,0x0du},{0x80u,0x21u,0x0eu,0x0du,0x0du,0x02u},{0x80u,0x00u,0x01u,0x02u,0x00u,0x0cu},{0x80u,0x21u,0x0eu,0x0cu,0x0cu,0x0du},{0x80u,0x00u,0x0bu,0x0bu,0x00u,0x01u},{0x80u,0x2au,0x0eu,0x01u,0x0du,0x0cu},{0x80u,0x2au,0x0eu,0x0cu,0x0du,0x01u},{0x80u,0x2au,0x0eu,0x0du,0x01u,0x0cu},{0x80u,0x00u,0x0bu,0x0cu,0x00u,0x0du},{0x80u,0x00u,0x02u,0x02u,0x00u,0x0cu},{0x80u,0x21u,0x0eu,0x0cu,0x0cu,0x0bu},{0x80u,0x2au,0x0eu,0x0du,0x0bu,0x02u}};
const mcuxClOsccaPkc_FUPEntry_t mcuxClOsccaSm2_FUP_Sign_Check_r[5] = {{0x10u,0x00u,0xbfu,0x77u,0x12u,0x88u},{0x80u,0x21u,0x23u,0x18u,0x01u,0x0bu},{0x80u,0x00u,0x0bu,0x22u,0x07u,0x0au},{0x80u,0x33u,0x0au,0x0au,0x07u,0x0bu},{0x80u,0x2au,0x07u,0x0bu,0x07u,0x0fu}};
const mcuxClOsccaPkc_FUPEntry_t mcuxClOsccaSm2_FUP_Sign_Compute_s[22] = {{0x10u,0x00u,0x01u,0x3eu,0x7fu,0x8au},{0x80u,0x00u,0x0bu,0x22u,0x07u,0x1eu},{0x80u,0x21u,0x23u,0x13u,0x0bu,0x0au},{0x80u,0x00u,0x0au,0x22u,0x07u,0x20u},{0x80u,0x00u,0x0fu,0x22u,0x07u,0x09u},{0x80u,0x21u,0x23u,0x1du,0x1eu,0x0au},{0x80u,0x00u,0x0au,0x14u,0x07u,0x0bu},{0x80u,0x00u,0x14u,0x1eu,0x07u,0x0cu},{0x80u,0x00u,0x1fu,0x09u,0x07u,0x0du},{0x80u,0x2au,0x23u,0x0bu,0x0cu,0x0au},{0x80u,0x2au,0x23u,0x0au,0x0du,0x19u},{0x80u,0x00u,0x19u,0x20u,0x07u,0x0bu},{0x80u,0x00u,0x19u,0x1eu,0x07u,0x0au},{0x80u,0x2au,0x23u,0x0bu,0x0au,0x0cu},{0x80u,0x00u,0x09u,0x15u,0x07u,0x0du},{0x80u,0x00u,0x0du,0x20u,0x07u,0x0au},{0x80u,0x21u,0x23u,0x0cu,0x0au,0x0bu},{0x80u,0x00u,0x09u,0x15u,0x07u,0x0du},{0x80u,0x00u,0x0du,0x1eu,0x07u,0x0au},{0x80u,0x2au,0x23u,0x0bu,0x0au,0x0cu},{0x80u,0x33u,0x0cu,0x0cu,0x07u,0x1cu},{0x80u,0x2au,0x07u,0x1cu,0x07u,0x1cu}};
const mcuxClOsccaPkc_FUPEntry_t mcuxClOsccaSm2_FUP_Sign_Double_Check_r[6] = {{0x10u,0x00u,0x16u,0x33u,0x79u,0x02u},{0x80u,0x21u,0x23u,0x18u,0x01u,0x0bu},{0x80u,0x00u,0x0bu,0x22u,0x07u,0x0au},{0x80u,0x33u,0x0au,0x0au,0x07u,0x0bu},{0x80u,0x2au,0x07u,0x0bu,0x07u,0x0au},{0x00u,0x0bu,0x0au,0x0au,0x0fu,0x0au}};
const mcuxClOsccaPkc_FUPEntry_t mcuxClOsccaSm2_FUP_Sign_Prepare_KD[6] = {{0x10u,0x00u,0xf9u,0x18u,0xa0u,0xc9u},{0x80u,0x00u,0x10u,0x22u,0x07u,0x0bu},{0x80u,0x00u,0x0bu,0x0du,0x07u,0x1du},{0x80u,0x00u,0x0cu,0x22u,0x07u,0x15u},{0x80u,0x21u,0x23u,0x16u,0x0cu,0x0au},{0x80u,0x00u,0x0au,0x22u,0x07u,0x1fu}};
const mcuxClOsccaPkc_FUPEntry_t mcuxClOsccaSm2_FUP_Sign_RPlusK[7] = {{0x10u,0x00u,0x6cu,0x5cu,0x14u,0x7eu},{0x80u,0x00u,0x0bu,0x22u,0x07u,0x14u},{0x80u,0x00u,0x0du,0x14u,0x07u,0x0cu},{0x80u,0x00u,0x0bu,0x14u,0x07u,0x0du},{0x80u,0x21u,0x23u,0x0du,0x0cu,0x0au},{0x80u,0x33u,0x0au,0x0au,0x07u,0x0bu},{0x80u,0x2au,0x07u,0x0bu,0x07u,0x0bu}};
const mcuxClOsccaPkc_FUPEntry_t mcuxClOsccaSm2_FUP_UpdateZ[6] = {{0x10u,0x00u,0xacu,0xbeu,0x7cu,0x7fu},{0x00u,0x0eu,0x01u,0x01u,0x25u,0x14u},{0x00u,0x0eu,0x02u,0x02u,0x25u,0x15u},{0x80u,0x2au,0x0eu,0x00u,0x02u,0x19u},{0x80u,0x00u,0x03u,0x0fu,0x00u,0x0bu},{0x00u,0x0eu,0x0bu,0x0bu,0x25u,0x0fu}};
MCUX_CSSL_ANALYSIS_STOP_PATTERN_FUP_PROGRAM()





MCUX_CSSL_ANALYSIS_START_PATTERN_DESCRIPTIVE_IDENTIFIER()
MCUX_CSSL_ANALYSIS_STOP_PATTERN_DESCRIPTIVE_IDENTIFIER()

MCUX_CSSL_ANALYSIS_START_PATTERN_DESCRIPTIVE_IDENTIFIER()
MCUX_CSSL_ANALYSIS_STOP_PATTERN_DESCRIPTIVE_IDENTIFIER()












MCUX_CSSL_ANALYSIS_START_PATTERN_DESCRIPTIVE_IDENTIFIER()
MCUX_CSSL_ANALYSIS_STOP_PATTERN_DESCRIPTIVE_IDENTIFIER()

MCUX_CSSL_ANALYSIS_START_PATTERN_DESCRIPTIVE_IDENTIFIER()
MCUX_CSSL_ANALYSIS_STOP_PATTERN_DESCRIPTIVE_IDENTIFIER()





